@@ -59,7 +59,7 @@ class Sequential:
     self.early_stop_ = early_stop
     
   
-  def fit(self, x, y, batch_size=None, epochs=None,verbose=None, validation_split=None, early_stop = None):
+  def fit(self, x, y, batch_size=None, epochs=None,verbose=None, validation_split=None, early_stop = None, weights = None):
     
     if len(y.shape) == 1:
       y = y.reshape(-1,1)
@@ -74,6 +74,8 @@ class Sequential:
       validation_split = self.validation_split_
     if early_stop is None:
       early_stop = self.early_stop_
+    if weights is not None:
+      self.loss_.set_weight(weights)
 
     self.metrics_per_batch = {}
 
